@@ -15,7 +15,6 @@ OC.L10N.register(
     "Copy link" : "نسخ الرابط",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
     "can edit" : "يمكن التعديل",
-    "Address book name" : "اسم دفتر العناوين",
     "First name" : "الإسم",
     "Last name" : "اللقب",
     "Display name" : "الاسم المعروض",
@@ -75,7 +74,6 @@ OC.L10N.register(
     "Social network" : "شبكة اجتماعية",
     "Relative" : "مرتبط",
     "None" : "لا شيء",
-    "Unknown" : "مجهول",
-    "Timezone" : "المنطقة الزمنية"
+    "Unknown" : "مجهول"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
