@@ -1,21 +1,36 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Contactos",
-    "All contacts" : "Todos los contactos",
     "Details" : "Detalles",
+    "All contacts" : "Todos los contactos",
+    "Contacts" : "Contactos",
+    "Loading contacts …" : "Cargando contactos ...",
     "Download" : "Descargar",
-    "Delete" : "Borrar",
     "Groups" : "Grupos",
-    "New contact" : "Nuevo contacto",
-    "Copy link" : "Copiar liga",
+    "Group name" : "Nombre del grupo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
+    "Delete" : "Borrar",
+    "Copy link" : "Copiar liga",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "Import into" : "Importar a",
+    "can edit" : "puede editar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
+    "Display name" : "Nombre a desplegar",
+    "Last modified" : "Última modificación",
+    "Invalid image" : "Imagen inválida",
+    "Name" : "Nombre",
+    "Title" : "Título",
+    "Cancel" : "Cancelar",
+    "Address book" : "Libreta de direcciones",
+    "New contact" : "Nuevo contacto",
+    "No results" : "No hay resultados",
+    "Close" : "Cerrar",
+    "Import" : "Importar",
+    "Not grouped" : "No agrupado",
+    "Email" : "Correo electrónico",
+    "Contact" : "Contacto",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -23,6 +38,7 @@ OC.L10N.register(
     "Suffix" : "Sufijo",
     "Notes" : "Notas",
     "Website" : "Sitio web",
+    "Location" : "Ubicación",
     "Federated Cloud ID" : "Id de nube federada",
     "Home" : "Particular",
     "Work" : "Trabajo",
@@ -36,7 +52,6 @@ OC.L10N.register(
     "Birthday" : "Fecha de nacimiento",
     "Anniversary" : "Aniversario",
     "Date of death" : "Fecha de defunción",
-    "Email" : "Correo electrónico",
     "Instant messaging" : "Mensajería instantánea",
     "Phone" : "Teléfono fijo",
     "Mobile" : "Teléfono móvil",
@@ -49,7 +64,6 @@ OC.L10N.register(
     "Car" : "Auto",
     "Work pager" : "Localizador de trabajo",
     "Social network" : "Red social",
-    "Relationship" : "Relación",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
     "Mother" : "Madre",
@@ -64,6 +78,8 @@ OC.L10N.register(
     "Assistant" : "Asistente",
     "Gender" : "Género",
     "Female" : "Femenino",
-    "Male" : "Masculino"
+    "Male" : "Masculino",
+    "None" : "Ninguno",
+    "Unknown" : "Desconocido"
 },
 "nplurals=2; plural=(n != 1);");
