@@ -39,7 +39,6 @@ OC.L10N.register(
     "Select local file" : "ローカルファイルの選択",
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
     "Choose a vCard file to import" : "インポートするvCardファイルを選択",
-    "Address book name" : "アドレス帳名",
     "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
     "First name" : "名",
     "Last name" : "姓",
@@ -156,7 +155,6 @@ OC.L10N.register(
     "Male" : "男性",
     "None" : "なし",
     "Unknown" : "不明",
-    "Timezone" : "タイムゾーン",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
     "Unable to delete contact" : "連絡先を削除できません。",
