@@ -55,6 +55,9 @@ class InstagramProvider implements ISocialProvider {
 	 * @return bool
 	 */
 	public function supportsContact(array $contact):bool {
+		if (!array_key_exists("X-SOCIALPROFILE",$contact)) {
+			return false;
+		}
 		$socialprofiles = $this->getProfiles($contact);
 		return isset($socialprofiles) && count($socialprofiles) > 0;
 	}
